/*       -*- C++ -*- */
/** \file
********************************************************************
* $URL: svn+ssh://nalw02/home/alg/schlemme/svn/cextools/trunk/cex2pdf.cpp $
* $Id: cex2pdf.cpp 13 2008-04-21 08:52:07Z schlemme $
* $Date: 2008-04-21 10:52:07 +0200 (Mo, 21 Apr 2008) $
* $Revision: 13 $
* \author Tobias Schlemmer <keinstein@users.berlios.de>
* $Author: schlemme $
* \license LGPL
* 
* Main program.
*
* \addtogroup main
*
*\{
********************************************************************
*/
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <string>
#include <libxml++/libxml++.h>
#include <map>
#include <set>
#include <iostream>
#include <cairomm/context.h>
#include <cairomm/surface.h>
#include "cexfile.h"
#include "svgplot.h"
#include <getopt.h>

static struct option long_options[] =
{
  	{"line-width",required_argument,0,'l'},
	{"multi-file",no_argument,0,'m'},
	{"help",no_argument,0,'h'},
	{0,0,0,0}
};

char * progname;


/// print help text.
/** This function prints the usage help text.
*/
void usage() {
	printf("Usage %s [options] cexfile\n\n"
	       "     -h --help       print this help text\n"
	       "     -l --line-width set line width of the diagram\n"
	       "                     default: 1\n"
	       "     -m --multi-file generate multiple files\n",
	       progname);
}

/// main program
/** loads a .cex file and plots it.
    \todo Command line parsing
    \param argc Number of command line arguments
    \param argv array of command line arguments
*/
int main(int argc, char * argv[]) {
	std::string filename,basename,ext;
	std::string::size_type p;

	int c, optindex;
	progname = *argv;
	
	while ((c = getopt_long(argc,argv,"hl:m",long_options,&optindex))!= -1) 		{
		switch (c) {
			case 0: printf("0-Option.\n");
				return 1;
			case '?':
			case 'h':
				usage();
				return 0;
				break;
			case 'l':
				if (optarg)
					pdfplot::set_default_line_width(optarg);
				else {
					usage();
					return 1;
				}
				break;
			case 'm':
				pdfplot::set_default_multi_file();
				break;
			default:
				usage();
				return 1;
				break;
		}
	}

	if (argc - optind != 1) {
		usage();
		return 1;
	}
	else filename = std::string(argv[optind]);

	if (filename.substr(p=filename.length()-4,4) == ".cex") 
		basename=filename.substr(0,p);
	else {
		basename = filename;
	}

	cexfile::cexfile* file;
	try {

		file = new cexfile::cexfile(filename);
	} catch(const std::exception& ex) {
		std::cout << "Exception caught: " << ex.what() << std::endl;
		abort();
	}
 
#ifdef DEBUG
	std::cerr << *file;
#endif

	svgplot * plotter = new svgplot(file,basename);
	plotter->plot();
	delete plotter;
  
	return 0;
}

// \}
