/*       -*- C++ -*- */
/** \file
 ********************************************************************
 * $URL: svn+ssh://nalw02/home/alg/schlemme/svn/cextools/trunk/include/cexfile/attribute_label.h $
 * $Id: attribute_label.h 12 2008-02-26 15:45:35Z schlemme $
 * $Date: 2008-02-26 16:45:35 +0100 (Di, 26 Feb 2008) $
 * $Revision: 12 $
 * \author Tobias Schlemmer <keinstein@users.berlios.de>
 * $Author: schlemme $ 
 * \license LGPL
 * 
 * Attribute label class.
 ********************************************************************
 */	  
#ifndef CEXFILE_ATTRIBUTE_LABEL_H
#define CEXFILE_ATTRIBUTE_LABEL_H

#include "cexfile/label.h"
#include "cexfile/attribute.h"

namespace cexfile {
  /// single attribute label
  class attribute_label:protected label {
    /// id of the attribute
    attribute::idtype id;
  public:
    /// default constructor
    attribute_label():label(),id() {}
    /// standard constructor 
    /** \param Node XML node to be parsed 
     */
    attribute_label(const xmlpp::Node * Node);

    /// return the identifier, to which the label belongs;
    attribute::idtype get_id() const {return id;}
  };

  /// attribute_label set mapping the identifiers to the attribute_labels
  typedef std::map<attribute::idtype,attribute_label> attribute_label_s;

  /// add an attribute_label to the attribute_label set
  /** \relates attribute_label_s
      \relates attribute_label
      \param s set of %attribute labels
      \param c %attribute %label
      \return reference to the set \c s
  */
  inline attribute_label_s& operator += (attribute_label_s& s, 
					 const attribute_label c) {
    s[c.get_id()]=c;
    return s;
  }

  inline attribute_label::attribute_label (const xmlpp::Node * Node)
    :label()
  {
    if (!Node) throw xmlpp::validity_error("Empty attribute label node.");

#ifdef DEBUG
    std::cerr << "Attribute Label: " << Node -> get_path() << std::endl;
#endif

    position = point(Node);
    id = parse_single_node_attribute(Node,ATTRIBUTE_REFERENCE,
				     ID_ATTRIBUTE);
  }
}

#endif /* CEXFILE_ATTRIBUTE_LABEL_H */
