/*       -*- C++ -*- */
/** \file
 ********************************************************************
 * $URL: svn+ssh://nalw02/home/alg/schlemme/svn/cextools/trunk/include/cexfile/object_base.h $
 * $Id: object_base.h 12 2008-02-26 15:45:35Z schlemme $
 * $Date: 2008-02-26 16:45:35 +0100 (Di, 26 Feb 2008) $
 * $Revision: 12 $
 * \author Tobias Schlemmer <keinstein@users.berlios.de>
 * $Author: schlemme $ 
 * \license LGPL
 * 
 * %object base class.
 ********************************************************************
 */	  
#ifndef CEXFILE_OBJECT_BASE_H
#define CEXFILE_OBJECT_BASE_H

#include "cexfile/intent.h"



namespace cexfile {
  /// base class for everything that has an intent
  class object_base {
  protected:

    /// XML Node
    const xmlpp::Node *node;

    /// intent or attribute set
    intent attributes;
  public:

    /// default constructor
    object_base():attributes(),node(NULL) {}

    /// standard constructor
    /** \param Node XML node to be parsed 
     */
    object_base(const xmlpp::Node * Node);

    /// returns the attribute set
    /** \return intent of the object 
     */
    const intent & get_intent() const { return attributes;}

    /// compares two objects
    /** \param o the other %objcect
	\retval true if we are lower than \p o
    */
    bool operator < (const object_base & o) const 
    {
      return o.attributes < attributes;
    }

  };
  
  inline object_base::object_base(const xmlpp::Node * Node):node(Node) {
    if (!Node) 
      throw xmlpp::validity_error("Empty parent Node for object_base.");

#ifdef DEBUG
    std::cerr << "Object_base: " << Node -> get_path() << std::endl;
#endif

    attributes = intent(Node);
  }

}


#endif /* CEXFILE_OBJECT_BASE_H */
