/*       -*- C++ -*- */
/** \file
 ********************************************************************
 * $URL: svn+ssh://nalw02/home/alg/schlemme/svn/cextools/trunk/include/cexfile/rect.h $
 * $Id: rect.h 12 2008-02-26 15:45:35Z schlemme $
 * $Date: 2008-02-26 16:45:35 +0100 (Di, 26 Feb 2008) $
 * $Revision: 12 $
 * \author Tobias Schlemmer <keinstein@users.berlios.de>
 * $Author: schlemme $ 
 * \license LGPL
 * 
 * A rectangle class.
 ********************************************************************
 */	  
#ifndef CEXFILE_RECT_H
#define CEXFILE_RECT_H

#include "cexfile/point.h"


namespace cexfile {
  /// rectangle oriented parallel to the coordinate axis
  class rect {
  protected:
    /// first point of diagonale
    point start;
    /// second point of diagonale
    point end;
  public:

    /// default constructor
    rect():start(),end() {}

    /// create the rectangle from the two corner points
    /** \param p1 first point
	\param p2 second point 
    */
    rect(const point & p1, const point & p2):
      start(p1),
      end(p2) 
    {}

    /// return the first point
    /** \return reference to the first point
     */
    point & get_start() { return start; }

    /// return the first point
    /** \return const reference to the first point
     */
    const point & get_start() const { return start; }

    /// return the second point
    /** \return reference to the second  point
     */
    point & get_end() { return end; }

    /// return the second point
    /** \return const reference to the second  point
     */
    const point & get_end() const { return end; }
  };
  
  /// a list of rectangles
  typedef std::list<rect> rect_s;

  /// add a rectangle to the rectangle list
  /** \relates rect_s
      \relates rect
      \param s list of rectangles
      \param e rectangle to be added
      \return reference to the list after addign \p e
  */
  inline rect_s& operator += (rect_s& s, const rect e) {
    s.push_back(e);
    return s;
  }

}


#endif /* CEXFILE_RECT_H */
